@@ -12,8 +12,9 @@ import pyproject_hooks
 import pytest
 
 import build
+import build._builder
 
-from build import _importlib
+from build._compat import importlib as _importlib
 
 
 build_open_owner = 'builtins'
@@ -21,7 +22,7 @@ build_open_owner = 'builtins'
 
 DEFAULT_BACKEND = {
     'build-backend': 'setuptools.build_meta:__legacy__',
-    'requires': ['setuptools >= 40.8.0', 'wheel'],
+    'requires': ['setuptools >= 40.8.0'],
 }
 
 
@@ -374,6 +375,7 @@ def demo_pkg_inline(tmp_path_factory):
     return next(out.iterdir())
 
 
+@pytest.mark.contextvars
 @pytest.mark.isolated
 def test_build_with_dep_on_console_script(tmp_path, demo_pkg_inline, capfd, mocker):
     """
@@ -383,7 +385,7 @@ def test_build_with_dep_on_console_script(tmp_path, demo_pkg_inline, capfd, mock
     # to validate backend invocations contain the correct path we use an inline backend that will fail, but first
     # provides the PATH information (and validates shutil.which is able to discover the executable - as PEP states)
     toml = textwrap.dedent(
-        '''
+        """
         [build-system]
         requires = ["demo_pkg_inline"]
         build-backend = "build"
@@ -392,17 +394,17 @@ def test_build_with_dep_on_console_script(tmp_path, demo_pkg_inline, capfd, mock
         [project]
         description = "Factory ⸻ A code generator 🏭"
         authors = [{name = "Łukasz Langa"}]
-        '''
+        """
     )
     code = textwrap.dedent(
-        '''
+        """
         import os
         import shutil
         import sys
         print("BB " + os.environ["PATH"])
         exe_at = shutil.which("demo-pkg-inline")
         print("BB " + exe_at)
-        '''
+        """
     )
     (tmp_path / 'pyproject.toml').write_text(toml, encoding='UTF-8')
     (tmp_path / 'build.py').write_text(code, encoding='utf-8')
@@ -502,7 +504,8 @@ def test_metadata_path_no_prepare(tmp_dir, package_test_no_prepare):
         pathlib.Path(builder.metadata_path(tmp_dir)),
     ).metadata
 
-    assert metadata['name'] == 'test-no-prepare'
+    # Setuptools < v69.0.3 (https://github.com/pypa/setuptools/pull/4159) normalized this to dashes
+    assert metadata['name'].replace('-', '_') == 'test_no_prepare'
     assert metadata['Version'] == '1.0.0'
 
 
@@ -513,7 +516,8 @@ def test_metadata_path_with_prepare(tmp_dir, package_test_setuptools):
         pathlib.Path(builder.metadata_path(tmp_dir)),
     ).metadata
 
-    assert metadata['name'] == 'test-setuptools'
+    # Setuptools < v69.0.3 (https://github.com/pypa/setuptools/pull/4159) normalized this to dashes
+    assert metadata['name'].replace('-', '_') == 'test_setuptools'
     assert metadata['Version'] == '1.0.0'
 
 
@@ -546,7 +550,6 @@ def test_log(mocker, caplog, package_test_flit):
     builder.prepare('wheel', '.')
     builder.build('sdist', '.')
     builder.build('wheel', '.')
-    builder.log('something')
 
     assert [(record.levelname, record.message) for record in caplog.records] == [
         ('INFO', 'Getting build dependencies for sdist...'),
@@ -554,7 +557,6 @@ def test_log(mocker, caplog, package_test_flit):
         ('INFO', 'Getting metadata for wheel...'),
         ('INFO', 'Building sdist...'),
         ('INFO', 'Building wheel...'),
-        ('INFO', 'something'),
     ]
 
 
@@ -576,7 +578,7 @@ def test_log(mocker, caplog, package_test_flit):
     ],
 )
 def test_parse_valid_build_system_table_type(pyproject_toml, parse_output):
-    assert build._parse_build_system_table(pyproject_toml) == parse_output
+    assert build._builder._parse_build_system_table(pyproject_toml) == parse_output
 
 
 @pytest.mark.parametrize(
@@ -614,4 +616,4 @@ def test_parse_valid_build_system_table_type(pyproject_toml, parse_output):
 )
 def test_parse_invalid_build_system_table_type(pyproject_toml, error_message):
     with pytest.raises(build.BuildSystemTableValidationError, match=error_message):
-        build._parse_build_system_table(pyproject_toml)
+        build._builder._parse_build_system_table(pyproject_toml)
